Coverage for pages.testproj.documents.urls: 100%

# Coverage for pages.testproj.documents.urls : 100%

## 6 statements 6 run 0 excluded 0 missing

1 2 3 4 5 6 7 8 | from django.conf.urls.defaults import * from pages.testproj.documents.views import document_view from pages.http import pages_view urlpatterns = patterns('', url(r'(?P<document_id>[0-9]+)$', pages_view(document_view), name='document_details'), url(r'$', pages_view(document_view), name='document_root'), )